@@ -99,9 +99,7 @@ class BaseSQLDict(DictMixin):
         table = Table(self._tablename, self._meta,
             Column('sqldict_ns',  String(nssize), nullable=False, primary_key=True),
             Column('sqldict_key', String(keysize), nullable=False, primary_key=True),
-            Column('sqldict_key_int', Integer, nullable=True),
             Column('sqldict_val', String(valsize), nullable=False),
-            Column('sqldict_val_int', Integer, nullable=True),
             Column('sqldict_flags', Integer, nullable=False),
         )
         self._table = table
@@ -174,10 +172,10 @@ class BaseSQLDict(DictMixin):
         col = table.c.sqldict_val
         if sort == 1:
             if flags & self._F_VAL_INT:
-                col = table.c.sqldict_val_int
+                pass
         if sort == 2:
             if flags & self._F_KEY_INT:
-                col = table.c.sqldict_key_int
+                pass
         return col
 
 
@@ -198,11 +196,9 @@ class BaseSQLDict(DictMixin):
         query = query.where(table.c.sqldict_ns == ns)
         if sort == 1:
             #print 'sort 1'
-            query = query.order_by(table.c.sqldict_key_int)
             query = query.order_by(table.c.sqldict_key)
         if sort == 2:
             #print 'sort 2'
-            query = query.order_by(table.c.sqldict_val_int)
             query = query.order_by(table.c.sqldict_val)
         #print query
         result = conn.execute(query)
@@ -224,10 +220,8 @@ class BaseSQLDict(DictMixin):
                         table.c.sqldict_flags])
         query = query.where(table.c.sqldict_ns == ns)
         if sort == 1:
-            query = query.order_by(table.c.sqldict_key_int)
             query = query.order_by(table.c.sqldict_key)
         if sort == 2:
-            query = query.order_by(table.c.sqldict_val_int)
             query = query.order_by(table.c.sqldict_val)
         result = conn.execute(query)
         for row in result:
@@ -246,10 +240,8 @@ class BaseSQLDict(DictMixin):
                         table.c.sqldict_flags])
         query = query.where(table.c.sqldict_ns == ns)
         if sort == 1:
-            query = query.order_by(table.c.sqldict_key_int)
             query = query.order_by(table.c.sqldict_key)
         if sort == 2:
-            query = query.order_by(table.c.sqldict_val_int)
             query = query.order_by(table.c.sqldict_val)
         result = conn.execute(query)
         for row in result:
@@ -316,11 +308,9 @@ class BaseSQLDict(DictMixin):
         query = query.where(table.c.sqldict_ns == ns)
         if sort == 1:
             #print 'sort 1'
-            query = query.order_by(table.c.sqldict_key_int)
             query = query.order_by(table.c.sqldict_key)
         if sort == 2:
             #print 'sort 2'
-            query = query.order_by(table.c.sqldict_val_int)
             query = query.order_by(table.c.sqldict_val)
         #print query
         result = conn.execute(query)
